@@ -2,4 +2,6 @@ api_key = None
 client_id = None
 api_base = 'https://pls.senddots.com/api'
 
-from dots.invoice import Invoice
\ No newline at end of file
+from dots.invoice import Invoice
+from dots.transaction import Transaction
+from dots.user import User
